Class: Ariadne::UI::Dialog::Component

Inherits:
BaseComponent
  • Object
show all
Defined in:
app/components/ariadne/ui/dialog/component.rb

Overview

A Dialog is used to remove the user from the main application flow, to confirm actions, ask for disambiguation or to present small forms.

Constant Summary

Constants inherited from BaseComponent

BaseComponent::ACCEPT_ANYTHING

Constants included from ViewHelper

ViewHelper::HELPERS

Constants included from AttributesHelper

AttributesHelper::PLURAL_ARIA_ATTRIBUTES, AttributesHelper::PLURAL_DATA_ATTRIBUTES

Instance Method Summary collapse

Methods inherited from BaseComponent

audited_at, #class_for, #component, component_id, #component_id, component_name, generate_id, #html_attributes, i18n_scope, #merge_data_attributes, #merge_tailwind_classes, #options, stimulus_name, translate, #validate_aria_label!

Methods included from AttributesHelper

#aria, #data, #merge_aria, #merge_data, #merge_prefixed_attribute_hashes, #prepend_action, #prepend_controller, #prepend_data_attribute

Methods included from ViewComponent::StyleVariants

#merged_styles

Instance Method Details

#describedbyObject



92
93
94
# File 'app/components/ariadne/ui/dialog/component.rb', line 92

def describedby
  "#{@dialog_id}-description"
end

#labelledbyObject



88
89
90
# File 'app/components/ariadne/ui/dialog/component.rb', line 88

def labelledby
  "#{@dialog_id}-title"
end